﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Mvc.Ajax;

namespace MvcApplication6.Controllers
{
    using Models;

    public class TableTempData
    {
        public string FirstData { get; set; }
        public string SecondData { get; set; }
    }

    public static class TableTempDataGenerator
    {
        public static IQueryable<string[]> GetDatas()
        {
            const int dataSize = 1000;
            string firstDataFormat = "FirstData{0}";
            string secondDataFormat = "SecondData{0}";

            List<string[]> tableTempDatas = new List<string[]>();
            for(int i = 0 ; i < dataSize ; i++)
            {
                tableTempDatas.Add(new string[2]
                                       {
                                           string.Format(firstDataFormat, i),
                                           string.Format(secondDataFormat, i)
                                       });
            }
            return tableTempDatas.AsQueryable();
        }
    }

    [HandleError]
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            ViewData["Title"] = "Home Page";
            ViewData["Message"] = "Welcome to ASP.NET MVC!";

            HomeIndexDataModel dataModel = new HomeIndexDataModel() {PagedTableData = GetPagedData(null)};
            return View(dataModel);
        }

        public ActionResult GetPagedDataModel(int? pageIndex)
        {
            return View("PagedTable", GetPagedData(pageIndex));
        }

        private PagedTableData GetPagedData(int? pageIndex)
        {
            PagedTableData pageData = new PagedTableData();
            pageData.ColumnHeaders = new List<string>() {"FirstData", "SecondData"};
            pageData.TableId = "TableId";
            pageData.PagedList = TableTempDataGenerator.GetDatas()
                .ToPagedList(pageIndex == null ? 0 : pageIndex.Value, 10);
            pageData.ActionName = "GetPagedDataModel";

            return pageData;
        }

        public ActionResult About()
        {
            ViewData["Title"] = "About Page";

            return View();
        }

        public string CallAjaxAction(string name)
        {
            return string.Format("return name : {0}", name);
        }
    }
}
